<?php

/**
 * @file
 * Default theme implementation for comments.
 *
 * Available variables:
 * - $author: Comment author. Can be link or plain text.
 * - $content: An array of comment items. Use render($content) to print them all, or
 *   print a subset such as render($content['field_example']). Use
 *   hide($content['field_example']) to temporarily suppress the printing of a
 *   given element.
 * - $created: Formatted date and time for when the comment was created.
 *   Preprocess functions can reformat it by calling format_date() with the
 *   desired parameters on the $comment->created variable.
 * - $changed: Formatted date and time for when the comment was last changed.
 *   Preprocess functions can reformat it by calling format_date() with the
 *   desired parameters on the $comment->changed variable.
 * - $new: New comment marker.
 * - $permalink: Comment permalink.
 * - $submitted: Submission information created from $author and $created during
 *   template_preprocess_comment().
 * - $picture: Authors picture.
 * - $signature: Authors signature.
 * - $status: Comment status. Possible values are:
 *   comment-unpublished, comment-published or comment-preview.
 * - $title: Linked title.
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the following:
 *   - comment: The current template type, i.e., "theming hook".
 *   - comment-by-anonymous: Comment by an unregistered user.
 *   - comment-by-node-author: Comment by the author of the parent node.
 *   - comment-preview: When previewing a new or edited comment.
 *   The following applies only to viewers who are registered users:
 *   - comment-unpublished: An unpublished comment visible only to administrators.
 *   - comment-by-viewer: Comment by the user currently viewing the page.
 *   - comment-new: New comment since last the visit.
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 *
 * These two variables are provided for context:
 * - $comment: Full comment object.
 * - $node: Node object the comments are attached to.
 *
 * Other variables:
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 *
 * @see template_preprocess()
 * @see template_preprocess_comment()
 * @see template_process()
 * @see theme_comment()
 *
 * @ingroup themeable
 */
?>

<div class="direct-chat-messages">
  <!-- If the comment belongs to others not the node author -->
  <?php if($comment->uid !== $node->uid):?>
  <div class="direct-chat-msg">
	  <div class="direct-chat-info clearfix">
		<span class="direct-chat-name pull-left"><?php print $author; ?></span>
		<span class="direct-chat-timestamp pull-right"><?php if ($new): ?><i class="new"><?php print $new ?></i><?php endif; ?><?php print $permalink; ?> <?php print $created; ?></span>
	  </div>
	  <img class="direct-chat-img" src="<?php if($comment->picture != 0){print file_create_url($comment->picture->uri);}else{print url(path_to_theme().'/img/user.png');} ?>" width="128" height="128">
	  <div class="direct-chat-text">
		<?php 
		// We hide the comments and links now so that we can render them later.
        hide($content['links']);
	    print render($content); ?>
	  </div>
  </div>
  
  <!--If the comment belongs to the node author-->
  <?php else:?>
  <div class="direct-chat-msg right">
	  <div class="direct-chat-info clearfix">
		<span class="direct-chat-name pull-right"><?php print $author; ?></span>
		<span class="direct-chat-timestamp pull-left"><?php if ($new): ?><i class="new"><?php print $new ?></i><?php endif; ?><?php print $permalink; ?> <?php print $created; ?></span>
	  </div>
	  <img class="direct-chat-img" src="<?php if($comment->picture != 0){print file_create_url($comment->picture->uri);}else{print url(path_to_theme().'/img/user.png');} ?>" width="128" height="128">
	  <div class="direct-chat-text">
		<?php 
		// We hide the comments and links now so that we can render them later.
        hide($content['links']);
	    print render($content); ?>
	  </div>
  </div>
  <?php endif; ?>
  <?php print render($content['links']) ?>
</div>
  
<?php /* 
  

  <?php print render($title_prefix); ?>
  <h3<?php print $title_attributes; ?>><?php print $title ?></h3>
  <?php print render($title_suffix); ?>

  <div class="content comment-text"<?php print $content_attributes; ?>>
    <span class="username"><?php print $submitted; ?><span class="text-muted pull-right"></span></span><!-- /.username -->
	<?php
      
      print render($content);
    ?>
    <?php if ($signature): ?>
    <div class="user-signature clearfix">
      <?php print $signature ?>
    </div>
    <?php endif; ?>
  </div>

</div>
 */
 ?>